Struct CreateClientArgs

pub struct CreateClientArgs {
    pub target_chain_id: String,
    pub counterparty_chain_id: String,
    pub clock_drift: Option<Duration>,
    pub trusting_period: Option<Duration>,
    pub trust_threshold: Option<TrustThreshold>,
}

Fields

target_chain_id: String

Identifier of the chain that hosts the client

counterparty_chain_id: String

Identifier of the chain targeted by the client

clock_drift: Option<Duration>

The maximum allowed clock drift for this client.

The clock drift is a correction parameter. It helps deal with clocks that are only approximately synchronized between the source and destination chains of this client. The destination chain for this client uses the clock drift parameter when deciding to accept or reject a new header (originating from the source chain) for this client. If this option is not specified, a suitable clock drift value is derived from the chain configurations.

trusting_period: Option<Duration>

Override the trusting period specified in the config.

The trusting period specifies how long a validator set is trusted for (must be shorter than the chain’s unbonding period).

trust_threshold: Option<TrustThreshold>

Override the trust threshold specified in the configuration.

The trust threshold defines what fraction of the total voting power of a known and trusted validator set is sufficient for a commit to be accepted going forward.