pub enum KeysCmd {
Add(KeysAddCmd),
List(KeysListCmd),
Delete(KeysDeleteCmd),
Balance(KeysBalanceCmd),
}Expand description
keys subcommand
Variants
Add(KeysAddCmd)
Add a key to a chain from its keyring file or restore a key using its mnemonic
List(KeysListCmd)
List the private key file that was added to a chain
Delete(KeysDeleteCmd)
Delete key(s) from a configured chain
Balance(KeysBalanceCmd)
Retrieve the balance for a key from a configured chain