pub struct KeysAddCmd { /* private fields */ }Expand description
The data structure that represents the arguments when invoking the keys add CLI command.
The command has one argument and two exclusive flags:
The command to add a key from a file:
keys add [OPTIONS] --chain <CHAIN_ID> --key-file <KEY_FILE>
The command to restore a key from a file containing its mnemonic:
keys add [OPTIONS] --chain <CHAIN_ID> --mnemonic-file <MNEMONIC_FILE>
On *nix platforms, both flags also accept /dev/stdin as a value, which will read the key or the mnemonic from stdin.
The --key-file and --mnemonic-file flags cannot both be provided at the same time, this will cause a terminating error.
If successful the key will be created or restored, depending on which flag was given.