pub struct KeysBalanceCmd { /* private fields */ }Expand description
The data structure that represents the arguments when invoking the keys balance CLI command.
The command has one argument and one optional flag:
keys balance --chain <chain_id> --key-name <KEY_NAME>
If no key name is given, it will be taken from the configuration file. If successful the balance and denominator of the account, associated with the key name on the given chain, will be displayed.